.. _sampling-utils:

sampling-utils - Resampling Utilities
=====================================

Overview
--------

.. automodule:: mgkit.workflow.sampling_utils


Options
-------

.. click:: mgkit.workflow.sampling_utils:main
   :prog: sampling-utils
   :show-nested:
